\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{esaAI}[2023/09/12 modified article class]

% Passes and class options to the underlying article class
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions

% Load LaTeX's article class
\LoadClass{article}

% Page layout
\usepackage{geometry}
\geometry{left=2cm, right=2cm, top=3cm, bottom=3cm}
\setlength{\columnsep}{15pt}
\pagestyle{empty}

% Author block style
\usepackage{authblk}
\renewcommand\Authands{, }
\renewcommand\Affilfont{\itshape\small}

% Abstract style
\renewenvironment{abstract}
 {\noindent\small\bfseries}

% Remaining title page settings
\date{}   
\newcommand{\makeCustomtitle}{\maketitle
\thispagestyle{empty}}

% Set Text style
\usepackage[utf8]{inputenc} % allow utf-8 input
\usepackage[T1]{fontenc}    % use 8-bit T1 fonts
\usepackage{kpfonts}  
\linespread{1.025}   
% \parindent 15pt
% \parskip 1.05mm
\usepackage[activate={true,nocompatibility},final,tracking=true,kerning=true,spacing=true,factor=1100,stretch=10,shrink=10]{microtype}

% Image package
\usepackage{graphicx}

% Math packages
\usepackage{amsmath}
\usepackage{amssymb}

% Bibliography settings
\usepackage[giveninits=true,style=nature,sorting=none,citestyle=numeric-comp, maxcitenames = 6]{biblatex}
\AtEveryBibitem{\clearfield{note}}
\AtEveryBibitem{\clearfield{language}} 
\renewcommand*{\bibfont}{\footnotesize}
\addbibresource{library.bib}

% Caption settings
\usepackage[font=small,labelfont={bf}, figurename=Figure, tablename=Table]{caption}
\renewcommand{\thetable}{\arabic{table}}

% Section head settings
\usepackage{titlesec}
\titleformat{\section}{\normalfont\Large\raggedright\bfseries}{\thesection}{1em}{}
\titleformat{\subsection}{\normalfont\large\raggedright\bfseries}{\thesubsection}{1em}{}

% References
\usepackage[noabbrev,nameinlink, capitalise]{cleveref}

% Colors
% \usepackage{xcolor}
% \definecolor{newblue}{RGB}{0,57,158}
% \definecolor{newlightblue}{RGB}{0,155,219}
% \definecolor{newred}{RGB}{150,1,54}

% Hyperref
% \usepackage[hidelinks]{hyperref}
% \hypersetup{
%   colorlinks   = true, %Colours links instead of boxes
%   urlcolor     = newlightblue, %Colour for external hyperlinks
%   linkcolor    = newblue, %Colour of internal links
%   citecolor   = newblue %Colour of citations
% }       

\endinput